==> ktp-desktop-applets-15.04.3.tar.xz: ktp-desktop-applets-15.04.3/person/org.kde.person/metadata.desktop.cmake <==
[Desktop Entry]
Name=Person
Name[ast]=Persona
Name[ca]=Persona
Name[cs]=Osoba
Name[da]=Person
Name[de]=Person
Name[en_GB]=Person
Name[es]=Persona
Name[fi]=Henkilö
Name[fr]=Personne
Name[it]=Persona
Name[nl]=Persoon
Name[pl]=Osoba
Name[pt]=Pessoa
Name[pt_BR]=Pessoa
Name[ro]=Persoană
Name[ru]=Человек
Name[sk]=Osoba
Name[sl]=Oseba
Name[sr]=Особа
Name[sr@ijekavian]=Особа
Name[sr@ijekavianlatin]=Osoba
Name[sr@latin]=Osoba
Name[sv]=Person
Name[uk]=Особа
Name[x-test]=xxPersonxx
Name[zh_CN]=个人
Name[zh_TW]=人物
Comment=Makes a person easily accessible
Comment[ast]=Fai d'accesu cenciellu una persona
Comment[ca]=Fa accessible una persona fàcilment
Comment[cs]=Usnadňuje přístup k osobám
Comment[da]=Gør en person nemt tilgængelig
Comment[de]=Ermöglicht den einfachen Zugriff auf eine Person
Comment[en_GB]=Makes a person easily accessible
Comment[es]=Hace a una persona fácilmente accesible
Comment[fi]=Helppo pääsy henkilöön
Comment[fr]=Rendre une personne facilement accessible
Comment[it]=Rende una persona facilmente accessibile
Comment[nl]=Maakt een persoon gemakkelijk toegankelijk
Comment[pl]=Czyni osobę łatwo dostępną
Comment[pt]=Torna uma pessoa facilmente acessível
Comment[pt_BR]=Torna uma pessoa facilmente acessível
Comment[ro]=Face o persoană să fie accesibilă ușor
Comment[ru]=Виджет для быстрого начала разговора с человеком
Comment[sk]=Urobí osobu ľahko prístupnú
Comment[sl]=Napravi osebo enostavno dostopno
Comment[sr]=Чини особу лако доступном
Comment[sr@ijekavian]=Чини особу лако доступном
Comment[sr@ijekavianlatin]=Čini osobu lako dostupnom
Comment[sr@latin]=Čini osobu lako dostupnom
Comment[sv]=Gör en person lätt tillgänglig
Comment[uk]=Спрощує доступ до особи
Comment[x-test]=xxMakes a person easily accessiblexx
Comment[zh_CN]=访问他人变得简单
Comment[zh_TW]=輕鬆與人互動

Icon=applications-system
Type=Service
X-KDE-ServiceTypes=Plasma/Applet
X-Plasma-API=declarativeappletscript

X-KDE-PluginInfo-Author=Aleix Pol Gonzalez
X-KDE-PluginInfo-Email=aleixpol@blue-systems.com
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://plasma.kde.org/
X-KDE-PluginInfo-Category=Utilities
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Name=org.kde.person

X-Plasma-MainScript=ui/main.qml
X-Plasma-Requires-LaunchApp=Unused
X-Plasma-DefaultSize=200,300

==> ktp-desktop-applets-15.08.0.tar.xz: ktp-desktop-applets-15.08.0/person/org.kde.person/metadata.desktop.cmake <==
[Desktop Entry]
Name=Person
Name[ar]=شخص
Name[ast]=Persona
Name[ca]=Persona
Name[cs]=Osoba
Name[da]=Person
Name[de]=Person
Name[el]=Πρόσωπο
Name[en_GB]=Person
Name[es]=Persona
Name[fi]=Henkilö
Name[fr]=Personne
Name[gl]=Persoa
Name[it]=Persona
Name[ko]=사람
Name[nl]=Persoon
Name[pl]=Osoba
Name[pt]=Pessoa
Name[pt_BR]=Pessoa
Name[ro]=Persoană
Name[ru]=Человек
Name[sk]=Osoba
Name[sl]=Oseba
Name[sr]=Особа
Name[sr@ijekavian]=Особа
Name[sr@ijekavianlatin]=Osoba
Name[sr@latin]=Osoba
Name[sv]=Person
Name[tr]=Kişi
Name[uk]=Особа
Name[x-test]=xxPersonxx
Name[zh_CN]=个人
Name[zh_TW]=人物
Comment=Makes a person easily accessible
Comment[ast]=Fai d'accesu cenciellu una persona
Comment[ca]=Fa accessible una persona fàcilment
Comment[cs]=Usnadňuje přístup k osobám
Comment[da]=Gør en person nemt tilgængelig
Comment[de]=Ermöglicht den einfachen Zugriff auf eine Person
Comment[el]=Καθιστά ένα πρόσωπο προσβάσιμο εύκολα
Comment[en_GB]=Makes a person easily accessible
Comment[es]=Hace a una persona fácilmente accesible
Comment[fi]=Helppo pääsy henkilöön
Comment[fr]=Rendre une personne facilement accessible
Comment[gl]=Permite acceder facilmente a unha persoa.
Comment[it]=Rende una persona facilmente accessibile
Comment[ko]=특정 사람과 빠르게 대화합니다
Comment[nl]=Maakt een persoon gemakkelijk toegankelijk
Comment[pl]=Czyni osobę łatwo dostępną
Comment[pt]=Torna uma pessoa facilmente acessível
Comment[pt_BR]=Torna uma pessoa facilmente acessível
Comment[ro]=Face o persoană să fie accesibilă ușor
Comment[ru]=Виджет для быстрого начала разговора с человеком
Comment[sk]=Urobí osobu ľahko prístupnú
Comment[sl]=Napravi osebo enostavno dostopno
Comment[sr]=Чини особу лако доступном
Comment[sr@ijekavian]=Чини особу лако доступном
Comment[sr@ijekavianlatin]=Čini osobu lako dostupnom
Comment[sr@latin]=Čini osobu lako dostupnom
Comment[sv]=Gör en person lätt tillgänglig
Comment[tr]=Bir kişiyi kolay erişilebilir yapar
Comment[uk]=Спрощує доступ до особи
Comment[x-test]=xxMakes a person easily accessiblexx
Comment[zh_CN]=访问他人变得简单
Comment[zh_TW]=輕鬆與人互動

Icon=applications-system
Type=Service
X-KDE-ServiceTypes=Plasma/Applet
X-Plasma-API=declarativeappletscript

X-KDE-PluginInfo-Author=Aleix Pol Gonzalez
X-KDE-PluginInfo-Email=aleixpol@blue-systems.com
X-KDE-PluginInfo-Name=person
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://plasma.kde.org/
X-KDE-PluginInfo-Category=Utilities
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Name=org.kde.person

X-Plasma-MainScript=ui/main.qml
X-Plasma-Requires-LaunchApp=Unused
X-Plasma-DefaultSize=200,300
